# Digital Forensics Investigative Questions
  
<img src="/site/docs/assets/dfiq-blue.png" width="100" alt="DFIQ Logo">

DFIQ is a collection of Digital Forensics Investigative Questions and the approaches to answering them.
The goal of the project is to build a comprehensive catalog of investigative knowledge to help drive 
consistent, thorough, and explainable investigations.

## Key Aspects of DFIQ:

* DFIQ is a catalog of investigative knowledge, centered on [Questions](https://dfiq.org/questions)
* Uses the concept of [Scenarios](https://dfiq.org/scenarios) to logically group Questions and help structure investigations
* Stores [data](/dfiq/data) in an easily-readable, tool-agnostic format (YAML) to be used by others
